Documentation
¶
Index ¶
- func BuildNumber(curLine int, n int, maxOffset int, rln bool) string
- func BuildSpaces(maxOffset int) string
- func Colorise(data string, c ascii.Color) string
- func VisibleSubString(text string, start int, end int) string
- type TUI
- func (tui *TUI) BuidASCII()
- func (ui *TUI) BuildCommandBar(curdata string) string
- func (ui *TUI) BuildLine(str []rune, show bool, start, end int, i int) string
- func (ui *TUI) BuildLowerBar(x int, y int, curdata string, message string, cmd string) string
- func (ui *TUI) BuildTabs(tabs []string, curTab int, show bool) string
- func (ui *TUI) Center(l []rune) string
- func (tui *TUI) GetASCIIInfo(index int) []rune
- func (tui *TUI) TermSizeMonitor(fdOut int)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BuildSpaces ¶
func VisibleSubString ¶
* So here is where I build the actual line, including the ASCII escape sequences * If I just use line.data[start:end], I'll get something like this: * * 033[0m and some text * * Here I just ignore the escape sequences and don't count them, so I can use them
Types ¶
type TUI ¶
type TUI struct {
XScroll int
YScroll int
CurRow int
CurOff int
W, H int
Save bool
ShowHello bool // show ascii art in empty Bard
Message string
Hello [][]rune // ascii art in empty Bard
Redraw chan bool
// contains filtered or unexported fields
}
func (*TUI) BuildCommandBar ¶
func (*TUI) BuildLowerBar ¶
func (*TUI) GetASCIIInfo ¶
func (*TUI) TermSizeMonitor ¶
This function is called in the main.go file in a goroutine. Here I just recalculate the terminal size and adjust Bard to it
Click to show internal directories.
Click to hide internal directories.